@@ -389,7 +389,8 @@ def _after_restore(ctx, conn, config, no_dev_scripts, no_remove_webassets):
     is_flag=True,
     help="Example if some extensions are missing (replication)",
 )
-@click.option("--dbname")
+@click.option("-d", "--dbname", help="Restore as dbname")
+@click.option("-f", "--dbfilter", help="Filter db names")
 @pass_config
 @click.pass_context
 def restore_db(
@@ -403,12 +404,11 @@ def restore_db(
     exclude_tables,
     verbose,
     ignore_errors,
+    dbfilter,
     dbname,
 ):
     if not filename:
-        filename = _inquirer_dump_file(
-            config, "Choose filename to restore", (dbname or config.dbname)
-        )
+        filename = _inquirer_dump_file(config, "Choose filename to restore", dbfilter)
     if not filename:
         return
     if not (dbname or config.dbname):
@@ -634,7 +634,7 @@ def _restore_dump(
         __rename_db_drop_target(
             conn.clone(dbname="postgres"), DBNAME_RESTORING, dbname or config.dbname
         )
-        _remove_postgres_connections(conn.clone(dbname=dest_db))
+        _remove_postgres_connections(conn, dest_db)
 
     finally:
         if config.run_postgres and config.use_docker:
@@ -665,9 +665,11 @@ def _add_cronjob_scripts(config):
     }
 
 
-def _inquirer_dump_file(config, message, filter):
+def _inquirer_dump_file(config, message, _filter):
     BACKUPDIR = Path(config.dumps_path)
     __files = _get_dump_files(BACKUPDIR)
+    if _filter:
+        __files = list(filter(lambda x: _filter.lower() in x[1].lower(), __files))
     filename = inquirer.prompt([inquirer.List("filename", message, choices=__files)])
     if filename:
         filename = filename["filename"][1]
