@@ -1,4 +1,5 @@
 import traceback
+import threading
 from .tools import bashfind
 import json
 import arrow
@@ -235,6 +236,7 @@ def internal_reload(
     no_gimera_apply=False,
     include_src=False,
 ):
+    threading.currentThread().config = config
     ensure_project_name(config)
     additional_docker_configuration_files = additional_docker_configuration_files or []
     defaults = {
@@ -287,6 +289,12 @@ def internal_reload(
 
     _execute_after_reload(config)
 
+    # update a possible robot file also
+    Commands.invoke(ctx, 'robot:make-var-file')
+
+    if float(ODOO_VERSION) >= 17.0:
+        if any(config.ODOO_PYTHON_VERSION.startswith(x) for x in ['3.9.', '3.8.', '3.7.']):
+            abort("Invalid python version - needs at least 3.10")
 
 def _execute_after_reload(config):
     execute_script(
@@ -1078,11 +1086,24 @@ def _merge_odoo_dockerfile(config, include_src):
         click.secho(f"Copying {dockerfile1} to {config.files['odoo_docker_file']}")
         config.files["odoo_docker_file"].write_text(Path(dockerfile1).read_text())
         for file in bashfind(config.WORKING_DIR, "Dockerfile.appendix"):
+            dir = file.parent / f"Dockerfile.appendix.dir"
             appendix = file.read_text()
             file = config.files["odoo_docker_file"]
             content = file.read_text() + "\n" + appendix
             content = content.replace("${PROJECT_NAME}", config.project_name)
             file.write_text(content)
+            # probably a dir?
+            if dir.exists():
+                dest = config.dirs['images'] / 'odoo' / "Dockerfile.appendix.dir"
+                if dest.exists() and dest.is_file():
+                    dest.unlink()
+                dest.mkdir(parents=True, exist_ok=True)
+                for part in dir.iterdir():
+                    if part.is_file():
+                        shutil.copy(part, dest)
+                    else:
+                        shutil.copytree(part, dest / part.name)
+        
 
         # append common docker config
         odoo_docker_file = config.files["odoo_docker_file"]
