@@ -1,3 +1,4 @@
+import time
 import click
 from subprocess import Popen, PIPE
 
@@ -33,13 +34,14 @@ def pull(ctx, config):
 
 @docker.command()
 @click.option("-b", "--build", is_flag=True)
+@click.option("-k", "--kill", is_flag=True)
 @pass_config
 @click.pass_context
-def dev(ctx, config, build):
+def dev(ctx, config, build, kill):
     ensure_project_name(config)
     if config.use_docker:
         from .lib_control_with_docker import dev as lib_dev
-    return lib_dev(ctx, config, build, kill=True)
+    return lib_dev(ctx, config, build, kill=kill)
 
 
 @docker.command(name="ps")
@@ -65,14 +67,15 @@ def execute(config, machine, args):
 @docker.command(name="kill")
 @click.argument("machines", nargs=-1)
 @click.option("-b", "--brutal", is_flag=True, help="dont wait")
+@click.option("-p", "--profile")
 @pass_config
 @click.pass_context
-def do_kill(ctx, config, machines, brutal=False):
+def do_kill(ctx, config, machines, brutal, profile):
     ensure_project_name(config)
     if config.use_docker:
         from .lib_control_with_docker import do_kill as lib_do_kill
 
-        lib_do_kill(ctx, config, machines, brutal=False)
+        lib_do_kill(ctx, config, machines, brutal=False, profile=profile)
 
 
 @docker.command()
@@ -87,7 +90,7 @@ def remove_volumes(ctx, config, dry_run):
     ensure_project_name(config)
     if not config.devmode:
         if not config.force:
-            abort("Please provide force option on non live systems")
+            abort("Please provide force option on non dev systems")
     if not config.use_docker:
         return
     subprocess.check_call(["sync"])
@@ -106,9 +109,17 @@ def remove_volumes(ctx, config, dry_run):
                     container_id = group[1:-1]
                     subprocess.run(["docker", "kill", container_id])
                     subprocess.check_call(["docker", "rm", "-fv", container_id])
-                    output = subprocess.check_output(
-                        ["docker", "volume", "rm", "-f", vol], encoding="utf8"
-                    )
+                    counter = 0
+                    while counter < 5:
+                        try:
+                            output = subprocess.check_output(
+                                ["docker", "volume", "rm", "-f", vol], encoding="utf8"
+                            )
+                            break
+                        except:
+                            click.secho(f"Removing the volume {vol} failed - waiting and retrying.", fg="red")
+                            time.sleep(2)
+                            counter += 1
 
         if dry_run:
             click.secho("Dry Run - didnt do it.")
@@ -183,6 +194,9 @@ def down(ctx, config, machines, volumes, remove_orphans, postgres_volume):
     ensure_project_name(config)
     from .lib_control_with_docker import down as lib_down
     from .lib_db_snapshots_docker_zfs import NotZFS
+    if not config.devmode:
+        if not config.force:
+            abort("Please provide force option on non live systems")
 
     print_prod_env(config)
 
@@ -226,24 +240,26 @@ def rebuild(ctx, config, machines):
 
 @docker.command()
 @click.argument("machines", nargs=-1)
+@click.option("-p", "--profile", default="auto")
 @pass_config
 @click.pass_context
-def restart(ctx, config, machines):
+def restart(ctx, config, machines, profile):
     ensure_project_name(config)
     from .lib_control_with_docker import restart as lib_restart
 
-    lib_restart(ctx, config, machines)
+    lib_restart(ctx, config, machines, profile=profile)
 
 
 @docker.command()
 @click.argument("machines", nargs=-1)
+@click.option("-p", "--profile", default="auto")
 @pass_config
 @click.pass_context
-def rm(ctx, config, machines):
+def rm(ctx, config, machines, profile):
     ensure_project_name(config)
     from .lib_control_with_docker import rm as lib_rm
 
-    lib_rm(ctx, config, machines)
+    lib_rm(ctx, config, machines, profile=profile)
 
 
 @docker.command()
