@@ -147,7 +147,9 @@ def do_kill(ctx, config, machines=[], brutal=False, profile="auto"):
                     safe_stop += [machine]
 
         if safe_stop:
-            __dc(config, ["stop", "-t", "20"] + safe_stop, profile=profile)  # persist data
+            __dc(
+                config, ["stop", "-t", "20"] + safe_stop, profile=profile
+            )  # persist data
     if config.devmode:
         __dc(config, ["kill"] + list(machines), profile=profile)
     else:
@@ -220,17 +222,18 @@ def rebuild(ctx, config, machines=[]):
     build(ctx, config, machines=machines, no_cache=True)
 
 
-def restart(ctx, config, machines=[]):
+def restart(ctx, config, machines=[], profile="auto"):
     machines = list(machines)
 
-    do_kill(ctx, config, machines=machines)
-    up(ctx, config, machines=machines, daemon=True)
+    # this is faster than docker restart: tested with normal project 6.75 seconds vs. 4.8 seconds
+    do_kill(ctx, config, machines=machines, profile=profile)
+    up(ctx, config, machines=machines, daemon=True, profile=profile)
 
 
-def rm(ctx, config, machines=[]):
+def rm(ctx, config, machines=[], profile="auto"):
     __needs_docker(config)
     machines = list(machines)
-    __dc(config, ["rm", "-f"] + machines)
+    __dc(config, ["rm", "-f"] + machines, profile=profile)
 
 
 def attach(ctx, config, machine):
