@@ -1,22 +1,23 @@
+import time
 import subprocess
 from pathlib import Path
 import sys
-import re
-import traceback
 import os
 import arrow
 import click
+from .tools import _is_db_initialized
 from .tools import abort
-from .tools import __replace_all_envs_in_str
 from .tools import _wait_postgres
 from .tools import _dropdb
 from .tools import __dcrun, _remove_postgres_connections, _execute_sql
 from .tools import exec_file_in_path
 from .cli import cli, pass_config, Commands
 from .lib_clickhelpers import AliasedGroup
-from .tools import __hash_odoo_password
 from .tools import _make_sure_module_is_installed
 from .tools import print_prod_env
+from .tools import _exists_db
+from .odoo_config import get_conn_autoclose
+from .tools import __dc
 
 
 @cli.group(cls=AliasedGroup)
@@ -109,6 +110,7 @@ def pgcli(config, dbname, params, host, port, user, password):
         conn = config.get_odoo_conn(inside_container=True).clone(dbname=dbname)
     return _pgcli(config, conn, params, use_docker_container=True)
 
+
 @db.command()
 @click.argument("dbname", required=False)
 @click.argument("params", nargs=-1)
@@ -176,12 +178,35 @@ def _pgcli(config, conn, params, use_docker_container=None):
     _psql(config, conn, params, bin="pgcli", use_docker_container=use_docker_container)
 
 
+def aggressive_drop_db(config, conn, dbname):
+    for i in range(3):
+        try:
+            _dropdb(config, conn, dbname)
+        except Exception as ex:
+            click.secho(f"Error at dropping db at attempt {i + 1}: {ex}", fg="red")
+            if config.run_postgres:
+                click.secho(
+                    f"Restarting postgres to remove any connections.", fg="yellow"
+                )
+                __dc(config, ["kill", "postgres"])
+                __dc(config, ["up", "-d", "postgres"])
+                _wait_postgres(config)
+        if not _exists_db(conn, dbname):
+            break
+        click.secho(
+            f"Database {dbname} was not dropped at first attempt. Retrying."
+        )
+        time.sleep(3)
+
+
 @db.command(name="reset-odoo-db")
 @click.argument("dbname", required=False)
 @click.option("--do-not-install-base", is_flag=True)
+@click.option("-W", "--no-overwrite", is_flag=True)
 @pass_config
 @click.pass_context
-def reset_db(ctx, config, dbname, do_not_install_base):
+def reset_db(ctx, config, dbname, do_not_install_base, no_overwrite):
+    import psycopg2
     collatec = True
     dbname = dbname or config.dbname
     if not dbname:
@@ -189,14 +214,31 @@ def reset_db(ctx, config, dbname, do_not_install_base):
     if config.run_postgres:
         Commands.invoke(ctx, "up", machines=["postgres"], daemon=True)
     _wait_postgres(config)
-    conn = config.get_odoo_conn().clone(dbname=dbname)
-    _dropdb(config, conn)
+
+    if no_overwrite:
+        try:
+            with get_conn_autoclose() as cr:
+                if _is_db_initialized(cr):
+                    click.secho("Database already initialized. Skipping.", fg="yellow")
+                    return
+        except Exception:
+            abort(
+                "Could not talk to postgres server - cannot decide if db is initialized or not. Aborting"
+            )
+
     conn = config.get_odoo_conn().clone(dbname="postgres")
+    aggressive_drop_db(config, conn, dbname)
+
     cmd2 = ""
     if collatec:
         cmd2 = "LC_CTYPE 'C' LC_COLLATE 'C' ENCODING 'utf8' TEMPLATE template0"
     cmd = f"create database {dbname} {cmd2} "
-    _execute_sql(conn, cmd, notransaction=True)
+    while True:
+        try:
+            _execute_sql(conn, cmd, notransaction=True)
+            break
+        except psycopg2.errors.DuplicateDatabase:
+            aggressive_drop_db(config, conn, dbname)
 
     # since odoo version 12 "-i base -d <name>" is required
     if not do_not_install_base:
@@ -342,11 +384,13 @@ ORDER BY total_bytes DESC;
         )
     )
 
+
 @db.command(help="Export as excel")
 @click.argument("sql", required=True)
 @pass_config
 def json(config, sql):
     import json as j
+
     conn = config.get_odoo_conn()
     columns, rows = _execute_sql(conn, sql, fetchall=True, return_columns=True)
     data2 = []
@@ -357,6 +401,7 @@ def json(config, sql):
     print("------------------------\n")
     print(data)
 
+
 @db.command(help="Export as excel")
 @click.argument("sql", required=True)
 @click.option("-f", "--file")
