@@ -16,25 +16,19 @@ import os
 import tempfile
 import click
 
-from wodoo.robo_helpers import _get_required_odoo_modules_from_robot_file
-from .tools import is_git_clean
 from gimera.repo import Repo
 from .tools import _make_sure_module_is_installed
-from .tools import autocleanpaper
 from .tools import get_hash
 from .tools import get_directory_hash
 from .tools import sync_folder
 from .tools import __dcrun
 from .tools import __cmd_interactive
 from .tools import __get_installed_modules
-from .tools import __concurrent_safe_write_file
 from .cli import cli, pass_config, Commands
 from .lib_clickhelpers import AliasedGroup
 from .tools import _execute_sql
-from .tools import table_exists
 from .tools import get_services
-from .tools import __try_to_set_owner
-from .tools import measure_time, abort
+from .tools import abort
 from .tools import _update_setting
 from .tools import _get_setting
 from .tools import get_git_hash
@@ -166,7 +160,7 @@ def run_tests(ctx, config):
             file = module.path / file
             ran_tests.append(file)
 
-            print(f"So far tests being run:")
+            click.secho(f"So far tests being run:", fg="yellow")
             for i, txtfile in enumerate(ran_tests, 1):
                 print(f"{i}: {txtfile}")
 
@@ -184,8 +178,9 @@ def run_tests(ctx, config):
 
                 res = run_test(file)
                 if res:
-                    print(
-                        f"Test {file} failed on first attempt. Resetting db and trying once more."
+                    click.secho(
+                        f"Test {file} failed on first attempt. Resetting db and trying once more.",
+                        fg="red",
                     )
                     reset_db()
                     res = run_test(file)
@@ -438,7 +433,6 @@ def update2(ctx, config, no_dangling_check, non_interactive, recover_view_error,
     help="Specify config file to use, for example config_update",
 )
 @click.option("--server-wide-modules")
-@click.option("--additional-addons-paths")
 @click.option(
     "--uninstall", is_flag=True, help="Executes just uninstallation of modules."
 )
@@ -504,7 +498,6 @@ def update(
     default_test_tags=False,
     config_file=False,
     server_wide_modules=False,
-    additional_addons_paths=False,
     uninstall=False,
     log=False,
     recover_view_error=False,
@@ -649,8 +642,6 @@ def update(
                     params += ["--test-tags=" + _effective_test_tags()]
                 if server_wide_modules:
                     params += ["--server-wide-modules", server_wide_modules]
-                if additional_addons_paths:
-                    params += ["--additional-addons-paths", additional_addons_paths]
                 if log:
                     params += [f"--log={log}"]
                 params += ["--config-file=" + config_file]
@@ -1018,19 +1009,25 @@ def show_install_state(config, suppress_error=False, missing_as_error=False):
 
 
 @odoo_module.command(name="show-addons-paths")
-def show_addons_paths():
+@pass_config
+def show_addons_paths(config):
     from .odoo_config import get_odoo_addons_paths
 
-    paths = get_odoo_addons_paths()
+    paths = get_odoo_addons_paths(
+        additional_addons_paths=config.ADDITIONAL_ADDONS_PATHS.split(",")
+    )
     for path in paths:
         click.echo(path)
 
 
 @odoo_module.command(name="show-conflicting-modules")
-def show_conflicting_modules():
+@pass_config
+def show_conflicting_modules(config):
     from .odoo_config import get_odoo_addons_paths
 
-    get_odoo_addons_paths()
+    get_odoo_addons_paths(
+        additional_addons_paths=config.ADDITIONAL_ADDONS_PATHS.split(",")
+    )
 
 
 def _exec_update(config, params, non_interactive=False, stdout=False):
@@ -1623,3 +1620,4 @@ def scan_addons_paths(config, ctx):
 
 Commands.register(update)
 Commands.register(show_install_state)
+Commands.register(uninstall)
