@@ -121,7 +121,13 @@ def _get_required_odoo_modules_from_robot_file(filecontent):
         if "odoo-require:" in line:
             line = line.split(":", 1)[1].strip().split(",")
             line = [x.strip() for x in line]
-            yield from line
+            for module in line:
+                yield 'install', module
+        if "odoo-uninstall:" in line:
+            line = line.split(":", 1)[1].strip().split(",")
+            line = [x.strip() for x in line]
+            for module in line:
+                yield 'uninstall', module
 
 
 def get_odoo_modules(verbose, test_files, root_dir):
@@ -199,7 +205,7 @@ def _eval_robot_output(
 
     click.secho(f"Outputs are generated in {find_results_path}", fg="yellow")
     click.secho(
-        ("Watch the logs online at: " f"http://host:{config.PROXY_PORT}/robot-output")
+        ("Watch the logs online at: " f"{config.EXTERNAL_DOMAIN or 'http://localhost'}:{config.PROXY_PORT}/robot-output")
     )
 
     for line in test_results:
@@ -211,7 +217,8 @@ def _eval_robot_output(
     results_json.write_text(json.dumps(test_results, indent=4))
 
     if failds:
-        sys.exit(-1)
+        return False
+    return True
 
 
 def _select_robot_filename(file, run_all):
@@ -222,8 +229,45 @@ def _select_robot_filename(file, run_all):
         sys.exit(-1)
 
     if file:
+        # test if argument wants to use wildcart matching
+        if "*" in file:
+            wildcart_matches = []
+            for path in Path('.').glob(file):
+                wildcart_matches.append(str(path))
+
+            if len(wildcart_matches) == 0:
+                click.secho(f"No matching files for wildcart {file}", fg="red")
+                sys.exit(-1)
+
+            # only return files that have a match in testfiles
+            # as glob finds all files matching wildcart, not only valid robot test files
+            testset = []
+            for test in testfiles:
+                if str(test) in wildcart_matches:
+                    testset.append(test)
+
+            if len(testset) == 0:
+                click.secho(f"No matching tests for wildcart {file}", fg="red")
+                sys.exit(-1)
+
+            return testset
+
         match = [x for x in map(str, testfiles) if file in x]
         if len(match) > 1:
+            # test if passed file argument is a directory
+            # if so, return all robot test files located inside that folder
+            if os.path.isdir(file):
+                testset = []
+                for test in match:
+                    if test.startswith(file):
+                        testset.append(Path(test))
+
+                if len(testset) == 0:
+                    click.secho(f"No matching tests in folder {file}", fg="red")
+                    sys.exit(-1)
+
+                return testset
+
             if "/" in file:
                 match = [x for x in match if x == file]
             if len(match) > 1:
