@@ -1,3 +1,4 @@
+import grp
 import os
 from pwd import getpwnam  
 import sys
@@ -46,6 +47,7 @@ def _export_settings(config, forced_values):
     settings = MyConfigParser(config.files['settings'])
     if 'OWNER_UID' not in settings.keys():
         settings['OWNER_UID'] = whoami(id=True)
+    settings['DOCKER_GID'] = grp.getgrnam('docker').gr_gid
 
     # forced values:
     for k, v in forced_values.items():
@@ -90,15 +92,9 @@ def _collect_settings_files(config, quiet=False):
     for file in _files:
         if not Path(file).exists():
             continue
-        # click.secho(f"Using setting file: {file}", fg='blue')
-        root = Path(sys.argv[0]).parent
-        # if Path(file).relative_to(
-        try:
-            Path(file).relative_to(root)
-        except ValueError:
-            if not quiet:
-                click.secho(f">>>>>>>>>>>>>>>>>>> {file} <<<<<<<<<<<<<<<<<", fg='cyan')
-                click.secho(file.read_text())
+        if not quiet:
+            click.secho(f">>>>>>>>>>>>>>>>>>> {file} <<<<<<<<<<<<<<<<<", fg='cyan')
+            click.secho(file.read_text())
 
     return _files
 
