@@ -1,4 +1,6 @@
 import platform
+import passlib
+import csv
 import inspect
 import socket
 import uuid
@@ -60,6 +62,16 @@ def get_calling_function_variables():
     caller_frame = current_frame.f_back.f_back
     # Get the local variables of the caller
     caller_locals = caller_frame.f_locals
+
+    for k, v in current_frame.f_back.f_back.f_back.f_locals.items():
+        if k not in caller_locals:
+            caller_locals[k] = v
+    for k, v in current_frame.f_back.f_back.f_back.f_back.f_locals.items():
+        if k not in caller_locals:
+            caller_locals[k] = v
+    for k, v in current_frame.f_back.f_back.f_back.f_back.f_back.f_locals.items():
+        if k not in caller_locals:
+            caller_locals[k] = v
     return caller_locals
 
 
@@ -82,11 +94,15 @@ def odoorpc(config):
 
 def exe(*params, **kwparams):
     vars = get_calling_function_variables()
-    config = vars["config"]
-    PROXY_PORT = config.PROXY_PORT or 8069
+    try:
+        config = vars["config"]
+        PROXY_PORT = config.PROXY_PORT or 8069
+        pwd = config.DEFAULT_DEV_PASSWORD or "admin"
+    except KeyError:
+        PROXY_PORT = 8069
+        pwd = "admin"
     host = f"http://localhost:{PROXY_PORT}"
     username = "admin"
-    pwd = config.DEFAULT_DEV_PASSWORD or "admin"
     from .odoo_config import get_settings
 
     config = get_settings()
@@ -284,8 +300,8 @@ def _execute_sql(
         return _call_cr(connection)
 
 
-def _exists_db(conn):
-    sql = f"select count(*) from pg_database where datname='{conn.dbname}'"
+def _exists_db(conn, dbname):
+    sql = f"select count(*) from pg_database where datname='{dbname}'"
     conn = conn.clone()
     conn.dbname = "postgres"
     record = _execute_sql(conn, sql, fetchone=True)
@@ -448,32 +464,31 @@ def _makedirs(path):
     path.mkdir(exist_ok=True, parents=True)
 
 
-def _remove_postgres_connections(connection, sql_afterwards=""):
+def _remove_postgres_connections(connection, dbname, sql_afterwards=""):
     click.echo(f"Removing all current connections from {connection.dbname}")
-    if os.getenv("POSTGRES_DONT_DROP_ACTIVITIES", "") != "1":
-        if _exists_db(connection):
-            SQL = """
-                SELECT pg_terminate_backend(pg_stat_activity.pid)
-                FROM pg_stat_activity
-                WHERE pg_stat_activity.datname = '{}'
-                AND pid <> pg_backend_pid();
-            """.format(
-                connection.dbname, sql_afterwards
+    if os.getenv("POSTGRES_DONT_DROP_ACTIVITIES", "") == "1":
+        click.secho("It was asked to remove database sessions but POSTGRES_DONT_DROP_ACTIVITIES is set to 1 - so i wont do it")
+    if _exists_db(connection, dbname):
+        SQL = f"""
+            SELECT pg_terminate_backend(pg_stat_activity.pid)
+            FROM pg_stat_activity
+            WHERE pg_stat_activity.datname = '{dbname}'
+            AND pid <> pg_backend_pid();
+            """
+        _execute_sql(connection.clone(dbname="postgres"), SQL, notransaction=True)
+        if sql_afterwards:
+            _execute_sql(
+                connection.clone(dbname="postgres"),
+                sql_afterwards,
+                notransaction=True,
             )
-            _execute_sql(connection.clone(dbname="postgres"), SQL, notransaction=True)
-            if sql_afterwards:
-                _execute_sql(
-                    connection.clone(dbname="postgres"),
-                    sql_afterwards,
-                    notransaction=True,
-                )
 
 
 def __rename_db_drop_target(conn, from_db, to_db):
     if to_db in ("postgres", "template1"):
         raise Exception("Invalid: {}".format(to_db))
-    _remove_postgres_connections(conn.clone(dbname=from_db))
-    _remove_postgres_connections(conn.clone(dbname=to_db))
+    _remove_postgres_connections(conn, from_db)
+    _remove_postgres_connections(conn, to_db)
     _execute_sql(
         conn.clone(dbname="postgres"),
         (f"drop database if exists {to_db}"),
@@ -484,7 +499,7 @@ def __rename_db_drop_target(conn, from_db, to_db):
         (f"alter database {from_db} rename to {to_db};"),
         notransaction=True,
     )
-    _remove_postgres_connections(conn.clone(dbname=to_db))
+    _remove_postgres_connections(conn, to_db)
 
 
 def _merge_env_dict(env):
@@ -661,7 +676,7 @@ def get_docker_version():
     docker = search_env_path("docker")
     version = subprocess.check_output([docker, "--version"], encoding="utf8").strip()
     # support for stripping debian specific version suffixes
-    version = re.sub("\+dfsg[0-9]*,", "", version)
+    version = re.sub(r"\+dfsg[0-9]*,", "", version)
     # continue with normal version parsing
     version = list(map(int, version.split(" ")[2].replace(",", "").split(".")))
     return version
@@ -673,7 +688,8 @@ def __get_cmd(config, profile="auto"):
     else:
         cmd = config.commands["dc"]
     if profile:
-        cmd += ["--profile", profile]
+        if "--profile" not in cmd:
+            cmd += ["--profile", profile]
     cmd = [os.path.expandvars(x) for x in cmd]
     return cmd
 
@@ -898,8 +914,8 @@ def _get_dump_files(backupdir, fnfilter=None):
     return rows
 
 
-def _dropdb(config, conn):
-    if _exists_db(conn):
+def _dropdb(config, conn, dbname):
+    if _exists_db(conn, dbname):
         # TODO ask for name
         if not config.force:
             questions = [
@@ -913,14 +929,14 @@ def _dropdb(config, conn):
                 )
             ]
             answer = inquirer.prompt(questions)
-            if answer["name"] != conn.dbname:
-                abort((f"Dropping aborted - you did not answer: {conn.dbname}"))
+            if answer["name"] != dbname:
+                abort((f"Dropping aborted - you did not answer: {dbname}"))
     else:
-        click.echo("Database does not exist yet: {}".format(conn.dbname))
+        click.echo(f"Database does not exist yet: {dbname}")
     click.echo("Stopping all services and creating new database")
-    _remove_postgres_connections(conn, "drop database {};".format(conn.dbname))
+    _remove_postgres_connections(conn, dbname, f"drop database {dbname};")
 
-    click.echo("Database dropped {}".format(conn.dbname))
+    click.echo(f"Database dropped {dbname}")
 
 
 def remove_webassets(conn):
@@ -1019,8 +1035,7 @@ def __remove_tree(dir, retry=3, interval=2):
     if E:
         raise E
 
-
-def __hash_odoo_password(pwd):
+def _get_crypt_context():
     from .odoo_config import current_version
 
     if current_version() in [
@@ -1033,20 +1048,26 @@ def __hash_odoo_password(pwd):
         15.0,
         16.0,
     ]:
-        setpw = CryptContext(schemes=["pbkdf2_sha512", "md5_crypt"])
-        return setpw.encrypt(pwd)
-    elif current_version() in [
-        17.0,
-    ]:
+        return CryptContext(schemes=["pbkdf2_sha512", "md5_crypt"])
+    elif current_version() in [17.0, 18.0]:
         MIN_ROUNDS = 600_000
-        setpw = CryptContext(
+        return CryptContext(
             schemes=["pbkdf2_sha512", "plaintext"],
             deprecated=["auto"],
             pbkdf2_sha512__rounds=max(MIN_ROUNDS, 0),
         )
-        return setpw.encrypt(pwd)
     else:
-        raise NotImplementedError()
+        raise NotImplementedError(current_version())
+
+def __hash_odoo_password(pwd):
+    return _get_crypt_context().encrypt(pwd)
+
+def __verify_password(pwd, hash):
+    try:
+        valid, replacement = _get_crypt_context().verify_and_update(pwd, hash)
+    except passlib.exc.UnknownHashError:
+        return False
+    return valid
 
 
 def abort(msg, nr=1):
@@ -1111,8 +1132,10 @@ def __assure_gitignore(gitignore_file, content):
     if not p.exists():
         p.write_text(content + "\n")
         return
+    content = content.strip()
+    filecontent = gitignore_file.read_text().strip() + "\n"
     exists = [
-        l for l in gitignore_file.read_text().splitlines() if l.strip() == content
+        l for l in filecontent.splitlines() if l.strip() == content
     ]
     if not exists:
         with p.open("a") as f:
@@ -1160,7 +1183,7 @@ def _extract_python_libname(x):
     if "@" in x:
         # return vcs refs
         return x
-    regex = re.compile(r"[\w\-\_]*")
+    regex = re.compile(r"[\w\-\_\.]*")
     x = x.replace("-", "_")
     match = re.findall(regex, x)[0]
     return match
@@ -1565,7 +1588,7 @@ def _make_sure_module_is_installed(ctx, config, modulename, repo_url, update=Fal
                 branch=str(current_version()),
                 type="integrated",
             )
-            ctx.invoke(gimera_apply, repos=[str(path)], no_auto_commit=True)
+            ctx.invoke(gimera_apply, repos=[str(path)], no_auto_commit=True, non_interactive=True, no_patches=True)
 
             # if not yet there, then pack into "addons_framework"
             addons_paths = manifest.get("addons_paths", [])
@@ -1575,7 +1598,7 @@ def _make_sure_module_is_installed(ctx, config, modulename, repo_url, update=Fal
                 manifest["addons_paths"] = addons_paths
     if update:
         ctx.invoke(
-            gimera_apply, repos=[str(dest_path)], update=True, no_auto_commit=True
+            gimera_apply, repos=[str(dest_path)], update=True, no_auto_commit=True, non_interactive=True, no_patches=True
         )
     install = manifest.get("install", [])
     if modulename not in install:
@@ -1769,3 +1792,13 @@ def _parse_yaml(content):
     import yaml
 
     return yaml.safe_load(content)
+
+def _is_db_initialized(cr):
+    return _exists_table(cr, "ir_module_module")
+
+
+def _output_clipboard_csv(rows):
+    fieldnames = rows[0].keys()
+    writer = csv.DictWriter(sys.stdout, fieldnames=fieldnames)
+    writer.writeheader()
+    writer.writerows(rows)
\ No newline at end of file
